#
# spec file for package perl-File-Unpack
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-File-Unpack
Version:        0.70
Release:        8.5
Summary:        An strong archive file unpacker, based on mime-types
License:        GPL-1.0-or-later OR Artistic-1.0
Group:          Development/Libraries/Perl
Source:         http://search.cpan.org/CPAN/authors/id/J/JN/JNW/File-Unpack-%{version}.tar.gz
Patch0:         fix-xml-test.diff
Patch1:         https://patch-diff.githubusercontent.com/raw/jnweiger/perl-File-Unpack/pull/5.diff
Patch2:         https://patch-diff.githubusercontent.com/raw/jnweiger/perl-File-Unpack/pull/6.diff
Patch3:         https://patch-diff.githubusercontent.com/raw/jnweiger/perl-File-Unpack/pull/9.diff
Patch4:         https://patch-diff.githubusercontent.com/raw/jnweiger/perl-File-Unpack/pull/10.diff
Patch5:         https://patch-diff.githubusercontent.com/raw/jnweiger/perl-File-Unpack/pull/11.diff
Patch6:         https://patch-diff.githubusercontent.com/raw/jnweiger/perl-File-Unpack/pull/12.diff
URL:            https://github.com/jnweiger/perl-File-Unpack
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  perl(Test::CheckManifest)
BuildRequires:  perl(Test::More)
BuildRequires:  perl(Test::Pod)
BuildRequires:  perl(Test::Pod::Coverage)

BuildRequires:  perl(Carp)
BuildRequires:  perl(Cwd)
BuildRequires:  perl(File::Compare)
BuildRequires:  perl(File::LibMagic)
BuildRequires:  perl(File::MimeInfo::Magic)
BuildRequires:  perl(File::Path)
BuildRequires:  perl(File::Temp)

# SLES11 does does not have this:
BuildRequires:  perl(Compress::Raw::Lzma)
# (provider perl-Compress-Raw-Zlib is obsoleted by installed perl)
BuildRequires:  perl(BSD::Resource)
BuildRequires:  perl(Compress::Raw::Bzip2)
BuildRequires:  perl(Compress::Raw::Zlib) >= 2.024
BuildRequires:  perl(Filesys::Statvfs)
BuildRequires:  perl(IPC::Run)
BuildRequires:  perl(JSON)
BuildRequires:  perl(String::ShellQuote)
BuildRequires:  perl(Text::Sprintf::Named)
# shared-mime-info is a dependency of perl-File-MimeInfo
# file is a dependency of perl-File-LibMagic
BuildRequires:  fdupes
BuildRequires:  file >= 5.03
BuildRequires:  shared-mime-info >= 0.60

Requires:       perl(Carp)
Requires:       perl(Cwd)
Requires:       perl(File::LibMagic)
Requires:       perl(File::MimeInfo::Magic)
Requires:       perl(File::Path)
Requires:       perl(File::Temp)

%if 0%{?suse_version} >= 1110
# SLES11 does does not have this:
Requires:       perl(Compress::Raw::Lzma)
%endif
Requires:       perl(Compress::Raw::Bzip2)
Requires:       perl(Compress::Raw::Zlib)
# 2.024 is provided by perl-5.12.1 in 11.3
Requires:       file >= 5.03
Requires:       shared-mime-info >= 0.60
Requires:       perl(BSD::Resource)
Requires:       perl(Compress::Raw::Zlib) >= 2.024
Requires:       perl(Filesys::Statvfs)
Requires:       perl(IPC::Run)
Requires:       perl(JSON)
Requires:       perl(Text::Sprintf::Named)
# App-cpanminus provides a bogus String::ShellQuote. We need to go by package name here.
# Requires:       perl(String::ShellQuote)
Requires:       perl-String-ShellQuote

## refer to Unpack.pm:@builtin_mime_handlers and to the helper subdirectory
## to see what we might need:
# grep '# Requires: ' Unpack.pm helper/*

%if 0%{?suse_version} > 1110
# 11.1 and SLES11 say: unresolvable: nothing provides xz
BuildRequires:  xz
Requires:       xz
%else
Recommends:     xz
%endif

%if 0%{?suse_version} > 1320
BuildRequires:  lzip
Requires:       lzip
%else
Recommends:     lzip
%endif

BuildRequires:  poppler-tools
Requires:       poppler-tools

## The following BuildRequires is for testing existance only.
## If you cannot provide a package, you may remove it from both BuildRequires 
## and Requires, and move it over to Recommends.
BuildRequires:  binutils
BuildRequires:  bzip2
BuildRequires:  cabextract
BuildRequires:  cpio
%if 0%{?suse_version} >= 1500
BuildRequires:  mkisofs
%else
BuildRequires:  genisoimage
%endif
BuildRequires:  gzip
# Remove when p7zip-full is in all products
%if 0%{suse_version} > 1500
BuildRequires:  p7zip-full
%else
BuildRequires:  p7zip
%endif
BuildRequires:  rpm
BuildRequires:  sharutils
BuildRequires:  tar
BuildRequires:  unzip
Requires:       binutils
Requires:       bzip2
Requires:       cabextract
Requires:       cpio
%if 0%{?suse_version} >= 1500
Requires:       mkisofs
%else
Requires:       genisoimage
%endif
Requires:       gzip
# Remove when p7zip-full is in all products
%if 0%{suse_version} > 1500
Requires:       p7zip-full
%else
Requires:       p7zip
%endif
Requires:       rpm
Requires:       sharutils
Requires:       tar
Requires:       unzip
Recommends:     unrar poppler-tools xz upx antiword xar

%if 0%{?suse_version} < 1140
Requires:       perl = %{perl_version}
%else
%{perl_requires}
%endif
Requires:       file-unpack == %version

%description
File::Unpack is an unpacker for archives and files
(bz2/gz/zip/tar/cpio/iso/rpm/deb/cab/lzma/7z/rar/...).  We call
it strong, because it is not fooled by file suffixes, or multiply wrapped packages.
It reliably detects mime-types and recursivly descends into each archive found
until it finally exposes all unpackable payload contents. 
A precise logfile can be written, describing mimetypes and unpack actions.
Most of the known archive file formats are supported. Shell-script-style
plugins can be added to support additinal formats.

%package -n file-unpack
Summary:        Command line tool to unpack anything
Group:          Productivity/Archiving/Compression
Requires:       perl(File::Unpack) == %version

%description -n file-unpack
/usr/bin/file-unpack is a trivial command line frontend that
ships with the File::Unpack perl module.

%prep
%autosetup -p1 -n File-Unpack-%{version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

(cd contrib && %{__make} stringsx)

%install
%{__make} pure_install PERL_INSTALL_ROOT=%{buildroot}
mv $RPM_BUILD_ROOT/usr/bin/{file_unpack,file-unpack} || :
install -d       $RPM_BUILD_ROOT/usr/share/File-Unpack/helper/
install helper/* $RPM_BUILD_ROOT/usr/share/File-Unpack/helper/

%fdupes $RPM_BUILD_ROOT/usr/share/File-Unpack/

ln -s /usr/bin/file-unpack $RPM_BUILD_ROOT/usr/bin/file_unpack
ln -s /usr/bin/file-unpack $RPM_BUILD_ROOT/usr/bin/unpack-file
ln -s /usr/bin/file-unpack $RPM_BUILD_ROOT/usr/bin/unpack-file-deep
ln -s /usr/bin/file-unpack $RPM_BUILD_ROOT/usr/bin/unpack-deep
ln -s /usr/bin/file-unpack $RPM_BUILD_ROOT/usr/bin/file-unpack-deep

## CAUTION: a line beginning with . is a macro-expanded by nroff.
# echo .nf > file-unpack.1
# perl -Iblib/lib file-unpack.pl --help >> file-unpack.1 && true
# rm -rf file-unpack.1

cat <<EOF> file-unpack.pod
=pod

=head1 SYNOPSIS
EOF
perl file-unpack.pl --help >> file-unpack.pod && true
cat <<EOF1>> file-unpack.pod
=head1 REFERENCES

See also C<perldoc File::Unpack>
EOF1
pod2man file-unpack.pod > file-unpack.1
rm file-unpack.pod
echo file-unpack.1 >> MANIFEST

install -m0644 -D file-unpack.1 $RPM_BUILD_ROOT/%_mandir/man1/file-unpack.1
ln -s %_mandir/man1/file-unpack.1 $RPM_BUILD_ROOT/%_mandir/man1/unpack_file.1
install -m0755 -D contrib/stringsx $RPM_BUILD_ROOT/%_bindir/stringsx
rm contrib/stringsx # so that the Manifest in make check is not confused.

# FIXME: use ./Build install destdir=$RPM_BUILD_ROOT create_packlist=0
# maybe then we would not need to remove the .packlist files :-)
find %{buildroot} -type f -name .packlist -exec rm -f {} ';'

find %{buildroot} -depth -type d -exec rmdir {} 2>/dev/null ';'

%{_fixperms} %{buildroot}/*
%perl_process_packlist
%perl_gen_filelist

## seperate bin man from the main package 
mv %{name}.files /tmp/%{name}.files
sed -ie '/\/man\?/d' /tmp/%{name}.files
sed -ie '/\/bin\//d' /tmp/%{name}.files

%check
export RELEASE_TESTING=1
#%{__make} test

%files -f /tmp/%{name}.files
%defattr(-,root,root,-)
%doc README Changes
%dir /usr/share/File-Unpack
/usr/share/File-Unpack/*
%doc %_mandir/man3/*

%files -n file-unpack
%defattr(-,root,root)
/usr/bin/*
%doc %_mandir/man1/*

%changelog
* Mon Mar  4 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Tue Feb 23 2021 Sebastian Riedel <sriedel@suse.com>
- Take 12.diff from https://github.com/jnweiger/perl-File-Unpack/pull/12
* Wed Jul 10 2019 Stephan Kulow <coolo@suse.com>
- Take 11.diff from https://github.com/jnweiger/perl-File-Unpack/pull/11
* Wed Jul 10 2019 Stephan Kulow <coolo@suse.com>
- Remove perl-File-Unpack-fix-race.patch in favor of 9.diff
- Add 10.diff from yet another pull request:
  https://github.com/jnweiger/perl-File-Unpack/pull/10
* Sun Jun  9 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add perl-File-Unpack-fix-race.patch to make build reproducible
  (boo#1102408)
* Fri Jun 29 2018 kstreitova@suse.com
- require p7zip-full for TW as 7z binary needed by perl-File-Unpack
  was moved to this package (see bsc#899627 for more details about
  this change)
* Fri Feb 23 2018 adam.majer@suse.de
- use mkisofs to supply `isoinfo` program instead of genisoimage
* Sun Sep  3 2017 coolo@suse.com
- fix file list hackery
* Sat Apr  1 2017 coolo@suse.com
- add 6.diff from my pull request
* Thu Mar 16 2017 coolo@suse.com
- add 5.diff from pull request of micha
* Tue Feb 21 2017 coolo@suse.com
- add fix-xml-test.diff to fix tests on tumbleweed
* Fri Mar 13 2015 jw@owncloud.com
- Update to 0.70
  - added support for MacOS pkg files that are xar archives.
* Mon Jul 21 2014 jw@owncloud.com
- Added symlinks file_unpack_deep and unpack_deep to exploit the new semantics.
- Update to 0.69
  - fixed https://github.com/jnweiger/perl-File-Unpack/issues/2
  - Semantics change of file_unpack.pl:
    Default to one_shot unless $0 contains 'deep'. New --deep option to also switch this one.
    This is a move towards least surprise. No other unpacker has this deep feature.
  - Fixed builtin helper for application=x-lzip to conform to IPC::Run::run() semantics.
  - Added an example how to write a mime helper script to the documentation.
  - Fixed diagnostics in case a helper script fails.
* Thu Jun 12 2014 jnweiger@gmail.com
- perl-String-ShellQuote pulled in by name, to work around
  perl-App-cpanminus false positives.
* Mon Jan 27 2014 jw@suse.com
- 0.66	harmful filename test removed, fixing bnc#860561.
  The name may not match, when symlinking back. Readlink is the only thing that counts.
- _run_mime_helper() now returns diagnostics even when 'successful' so that we
  can see reasoning for 'passed'.
- added t/08-survive-corrupt.t to define behavoiur for good10.pdf and bad34.pdf
- registered the two new test files with t/02-mime.t and t/07-cmdline.t
* Tue Aug  6 2013 jw@suse.com
- 0.65 CPAN no longer fails with  'Using $< in a non-suffix rule context is a GNUmake idiom'
* Mon Jul 29 2013 jw@suse.com
- 0.64 fixed explosions on ksh:
  * assert writable dirs in _run_mime_helper while disassembling jail.
    needed for ksh/ast-base.2012-08-01.tar.bz2/src/cmd/pax/data/ro.dat
  * all rename()s in _run_mime_helper() equipped with or die.
  * DESTROY() now handles more cases: Adding the epilog when missing is paramount.
* Tue Jun 18 2013 jw@suse.com
- require lzip only for factoy. It is simply nowhere else.
* Fri Jun 14 2013 jw@suse.com
- 0.63 * supporting lzip, untested
* Tue May  7 2013 jw@suse.com
- 0.62 * support pax
* Mon Apr 29 2013 jw@suse.com
- 0.60 * report text/x-application-xml instead of application/xml
    for ordinary xml files.
* Tue Mar 26 2013 jw@suse.com
- 0.59  * helping upx to survive symlinks. "%%{lsrc}s" format added.
  * POD fixes from from anirvan/patch-1
  * application/msword helper added. Using antiword.
  * helper diagnostics improved: first line of stderr is captured in
  the log.
  * {verbose} control improved.
* Fri Feb  8 2013 jw@suse.com
- 0.58	- bugfix: {inside_archives} was not decremented after leaving an archive.
* Thu Feb  7 2013 jw@suse.com
- 0.57 - fixed -f to really allow crawling symlinks.
  * the logfile will contain the link name, not the link target.
  * it thus preserves the illusion that all is inside the destination tree.
  - The following command can now be used to recreate the logfile (and retry more unpacking)
  in $DIR:
  file_unpack -D $DIR -f -L $DIR.unpack.log $DIR
  - _run_mime_helper(): cleanup $jail_base added when cmd fails to run.
  Helper failure may still may result in missing files.
  - t/07-cmdline.t added.
* Tue Feb  5 2013 jw@suse.com
- 0.56	- guard _my_shell_quote against undef.
  - no 'running as root warning' when !{verbose}
  - Relax testsuite on test.mht
  - relax DESTROY to not start a logfile, when none is requested.
  - testsuite really silent now.
* Fri Jan 25 2013 jw@suse.com
- oops, t/data/test.mht  not included.
* Fri Jan 25 2013 jw@suse.com
- 0.55	- option --follow-file-symlinks or new(follow_file_symlinks => $yes) added;
  where $yes is 0, 1, or 2.
  We may want to use '1', if we are e.g. inside a legaldb_unpacked
  tree, where everything is a symlink. This usage is experimental.
  A value of '2' is hideous and requires studying perldoc Unpack.pm first.
  - tracking $self->{inside_archives} added. Also experimental.
* Thu Aug 23 2012 jw@suse.com
- attempting to build the C-Version of stringsx.
  RPM does not like this, it enforces noarch on me.
  - > unused
* Fri Mar  9 2012 jw@suse.com
- 0.54  - no longer add special files like fifos, sockets, dev nodes to the logfile.
  - loggable_pathname adds {srcdir => 'input'} if path is in $self->{input}
* Tue Feb 21 2012 jw@suse.com
- 0.53a file_unpack binary was not updated to actually use the
    new plaintext feature. Rerolled 0.53 tar ball.
* Fri Feb 17 2012 jw@suse.com
- 0.53  - new parameter -A and new(archive_name_as_dir=>1) added.
  - new(log_type => 'PLAIN') added, used unless -L
* Wed Feb  1 2012 jw@suse.com
- 0.52  - logfile: input menitoned on 'passed' items.
  - Makefile.PL now actually installs file_unpack (rt#73670).
  Man page is a hack. Sorry.
  - file_unpack can now unpack multiple archives on the command line.
  - helper/handler wording now consistently speaks of helpers.
* Wed Jan 25 2012 jw@suse.com
- 0.51  input archives that do not exist in destdir (because they were unpacked)
  now show up in the log prefixed with './input/./' unless fullpath.
* Tue Jan 24 2012 jw@suse.com
- 0.50 	made testsuite survive on SLE11_SP1, put IO::Handle::tell()
    inside eval to survive SLES11_SP1
* Mon Jan 23 2012 jw@suse.com
- 0.49	made survive ntop, in{file} must not modify, so that reopen inside mime() works.
* Tue Nov 29 2011 jw@suse.com
- 0.48   made compatible with perl-5.14.2 where qw() is (qw())
* Tue Oct  4 2011 jw@suse.com
- 0.47  Fixed rt#70885
* Thu Sep  8 2011 jw@novell.com
- 0.46  Incompatible change: unpacked filenames are now relative to destdir
  unless -F or ->new(log_fullname => 1)
  New parameter -P or ->new(log_params => {}) to feed params into the
  logfile.
* Fri May 27 2011 jw@novell.com
- 0.45	Added option world_readable=>1, to assert 0755/0444 modes for dirs/files.
* Fri May 20 2011 jw@novell.com
- 0.44	using syswrite in log() to catch errors.
* Thu May 12 2011 jw@novell.com
- 0.43 	Implemented no_op option in _run_mime_handler().
    Added -n option to file_unpack.pl
* Thu Apr 21 2011 jw@novell.com
- 0.42  Unexpected DESTROY handler closes json
  logfile properly with an {error} message, if any.
* Mon Apr 18 2011 jw@novell.com
- 0.41	Statistics in logfile about skipped (exclude and symlink) files.
* Sat Apr 16 2011 jw@novell.com
- 0.40	less verbose with differing destnames...
  Survive crashes in run().
  logfile json syntax preserved, even when terminating error message. No more trailing dummy "/":{}
* Wed Apr  6 2011 jw@novell.com
- 0.39 Try /._\d?/ name suffixes on collisions to avoid _fu_* directories if possible.
    Added _chmod_add() to help creating readable files and executable directories.
    Raised default maxfilesize from 100M to 2.5G, honors FILE_UNPACK_MAXFILESIZE too.
* Thu Mar 31 2011 jw@novell.com
- t/data/monotone.info was missing in MANIFEST
* Thu Mar 31 2011 jw@novell.com
- 0.38	Both File::LibMagic and File::MimeInfo::Magic fail on info files.
  Ask perl -T and return application/x-text-mixed in that case.
  Fixed comparison with RLIM_INFINITY, it evaluates -1.
* Tue Mar 29 2011 jw@novell.com
- fix manpage to not contain ./ macros.
* Mon Mar 28 2011 jw@novell.com
- added a primitive man-page using .nf
* Mon Mar 28 2011 jw@novell.com
- 0.37	Fixed setrlimit() calls, to not explode, when the limit is already lower.
  Minor cleanup.
* Fri Mar 25 2011 jw@novell.com
- 0.36	removed dependency on lsof, in favour of /proc and builtin
    _children_fuser(). tick-tick now shows the percentage of the fastest moving fd.
* Thu Mar 24 2011 jw@novell.com
- 0.35	tested with gcc-ejc, parsing lsof output with $u->run() during $u->run(). Yeah!
  Libmagic perl module explodes with malformed utf8, assert LC_ALL=C.
  run() untaint argv0. needed for running helpers under -T
  Empty file is text/x-empty now. not application/x-empty.
* Tue Mar 22 2011 coolo@novell.com
- unrar is unfree software
* Thu Mar 10 2011 jw@novell.com
- updated to 0.32,
  fixed logfile JSON syntax.
  fixed setrlimit().
* Wed Mar  9 2011 jw@novell.com
- updated to 0.31, docu fixes. list() mode added.
* Tue Dec 14 2010 jw@novell.com
- 0.29  Mention /usr/bin/file_unpack in perldoc
* Sun Dec  5 2010 jw@novell.com
- added /usr/bin/unpack_file as a symlink
- 0.28  Look only at files and dirs, ignore special files.
  Reading a pipe could block us endlessly.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Sep 24 2010 jw@novell.com
- 0.27	new feature in mime(): attempt full file access
  not only if flm reports currupt, but also when it reports
  a/octet-stream. This helps to recognize a/x-iso9660-image
  Added .iso by including my old unpack_iso.pl as a helper.
  Added .lha
* Fri Sep 10 2010 jw@novell.com
- 0.26	Added .upx; we are testing all application/*-executable for upx to get the mime type.
  Fixed test results on SLE-11, 02-mime.t now can match regexp too.
  Dependencies sharpened: file >= 5.03 shared-mime-info >= 0.60
* Wed Sep  8 2010 jw@novell.com
- 0.25 	Added .cpio, .deb, .cab, .7z
  Removed done_testing() for the sake of old Test::More on 11.1
* Wed Sep  8 2010 jw@suse.de
- 0.24  Fixed helper. There was a debug die :-)
* Wed Sep  1 2010 jw@novell.com
- 0.23  Added option one_shot, to new() and file_unpack.pl
  Added unpacking of: application/pdf, %%tar+lzma, %%rar, %%uuencode
  Added '# Requires: ....' comments with the builtin handlers to document
  the non-perlish dependencies.
  Fixed recognition of .xls -- File::LibMagic said corrupt, with only a short buffer.
  Swapped 2nd and 3rd parameter of _run_mime_handler(): mime helpers have now their
  suggested destname as second parameter.
  mime(): added suffix rules for 'text/plain' and 'application/octet-stream',
  to harvest even the least trusted source of information, in the absence
  of anything else.
  Implemented first draft of helper/text/=x-shellscript: tested embedded gzip.
  Added -L option to file_unpack.pl;
  _run_mime_handler() now untaints its argv. run() errors are now propagated.
  t/04-subdir.t now does a real-life unzip test, if unzip is available.
  Lowered $RECURSION_LIMIT to 200. 1000 takes ages with big files.
  Call bunzip2 with -f, but don't call xz with -f.
  Fixed unpack() to not hit 256 char limit per filename so easily.
  Tested mime_handler_dir(), now it actually works. Introduced a default directory
  /usr/share/File-Unpack/helper.
  Preparing env variable PERL5LIB for helpers.
  mime(): Fixed usage of LZMA alone decoder: count as positive, only of output appeared.
  text/x-shellscript: uudecode and shar support tested; works now.
* Mon Aug 30 2010 jw@novell.com
- 0.22	Fixed descending of destdir into subdirs of subdirs
  Added t/04-subdir.t,
  Added first support for running unpack() under -T
  Replaced MANIFEST.SKIP with a filter in t/manifest.t
  Fixed t/02-mime.t to survive missing shared-mime-info.
  (Makefile.PL cannot require non-perl packages, can it?)
* Wed Aug 25 2010 jw@novell.com
- 0.21 Added 'nothing-to-do' semantic for mime-helpers: Point back by symlink.
    Added helper/text=x-shellscript to demonstrate this.
    Made external mime-helpers work: registering, calling.
    Remember absolut path, call mime_type() correctly.
    Started to propagate errors from _run_mime_handler() to unpack().
    mime(): In SLES11 we get 'text/plain charset=utf-8' without semicolon.
* Tue Aug 24 2010 jw@novell.com
- 0.20 from cpan
